@@ -82,13 +82,54 @@ gm_audio_profile_choose_get_active (GtkWidget *choose)
   GtkTreeIter iter;
   GtkComboBox *combo = GTK_COMBO_BOX (choose);
   gchar *id;
-
+  GMAudioProfile *profile;
+  
   g_return_if_fail (GTK_IS_COMBO_BOX (choose));
   /* get active id */
   gtk_combo_box_get_active_iter (combo, &iter);
   gtk_tree_model_get (gtk_combo_box_get_model (combo), &iter,
                       ID_COLUMN, &id, -1);
-
+  
   /* look up gm_audio profile */
-  return gm_audio_profile_lookup (id);
+  profile = gm_audio_profile_lookup (id);
+  g_free (id);
+
+  return profile;
+}
+
+gboolean
+gm_audio_profile_choose_set_active (GtkWidget  *choose,
+				    const char *id)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  char *tmp;
+  
+  g_return_if_fail (GTK_IS_COMBO_BOX (choose));
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (choose));
+  
+  if (!gtk_tree_model_get_iter_first (model, &iter))
+    return FALSE;
+
+  while (1)
+    {
+      gtk_tree_model_get (model, &iter, ID_COLUMN, &tmp, -1);
+      if (!strcmp (tmp, id))
+	{
+	  gtk_combo_box_set_active_iter (GTK_COMBO_BOX (choose), &iter);
+	  g_free (tmp);
+	  return TRUE;
+	}
+      g_free (tmp);      
+      
+      if (!gtk_tree_model_iter_next (model, &iter))
+	break;
+    }
+
+  /* Fallback to first entry */
+  gtk_tree_model_get_iter_first (model, &iter);
+  gtk_combo_box_set_active_iter (GTK_COMBO_BOX (choose), &iter);
+  
+  return FALSE;
 }
